@@ -14,9 +14,6 @@
 #
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see <http://www.gnu.org/licenses/>.
-
-from __future__ import unicode_literals
-
 import sys
 import unittest
 
@@ -35,10 +32,6 @@ from byot import (
 )
 
 
-if sys.version_info >= (3,):
-    unicode = str
-
-
 class TestSectionMatcher(unittest.TestCase):
 
     def setUp(self):
@@ -662,11 +655,11 @@ bar=foo
         if sys.version_info < (3,):
             self.assertEqual(
                 '''Loop involving u'foo' while expanding "{foo}".''',
-                unicode(cm.exception))
+                str(cm.exception))
         else:
             self.assertEqual(
                 '''Loop involving 'foo' while expanding "{foo}".''',
-                unicode(cm.exception))
+                str(cm.exception))
 
     def test_indirect_loop(self):
         self.conf.store._load_from_string('''
@@ -884,7 +877,7 @@ bar = {foo}/2
             c.get('bar', expand=True)
         self.assertEqual(
             '''Option "foo" is not defined while expanding "{foo}/2".''',
-            unicode(cm.exception))
+            str(cm.exception))
 
     def test_cross_related_sections(self):
         c = self.get_config('/project/branch/path', '''
@@ -934,7 +927,7 @@ gbar = glob-bar
 
 class TestSharedStores(unittest.TestCase):
 
-    def test_store_is_shared(self):
+    def test_file_store_is_shared(self):
 
         class Stack(stacks.Stack):
 
@@ -948,3 +941,20 @@ class TestSharedStores(unittest.TestCase):
         g2 = Stack()
         # The two stacks share the same store
         self.assertIs(g1.store, g2.store)
+
+    def test_cmdline_store_is_shared(self):
+        cls1 = stacks.get_shared_store(stores.CommandLineStore())
+        cls2 = stacks.get_shared_store(stores.CommandLineStore())
+        self.assertIs(cls1, cls2)
+
+    def test_unique_memory_stacks(self):
+        s1 = stacks.MemoryStack(id='<string1>')
+        s2 = stacks.MemoryStack(id='<string2>')
+        self.assertIsNot(stacks.get_shared_store(s1.store),
+                         stacks.get_shared_store(s2.store))
+
+    def test_shared_memory_stack(self):
+        s1 = stacks.MemoryStack()
+        s2 = stacks.MemoryStack()
+        self.assertIs(stacks.get_shared_store(s1.store),
+                      stacks.get_shared_store(s2.store))
